==> qt3d-everywhere-opensource-src-5.15.16.zip: qt3d-everywhere-src-5.15.16/src/core/jobs/qaspectjob_p.h <==
/****************************************************************************
**
** Copyright (C) 2014 Klaralvdalens Datakonsult AB (KDAB).
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt3D module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QT3DCORE_QASPECTJOB_P_H
#define QT3DCORE_QASPECTJOB_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists for the convenience
// of other Qt classes.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <QtCore/QWeakPointer>

#include <Qt3DCore/private/qt3dcore_global_p.h>
#include <Qt3DCore/private/qsysteminformationservice_p_p.h>
#include <Qt3DCore/qt3dcore-config.h>

QT_BEGIN_NAMESPACE

namespace Qt3DCore {

class QAspectJob;
class QAspectManager;

class Q_3DCORE_PRIVATE_EXPORT QAspectJobPrivate
{
public:
    QAspectJobPrivate();
    virtual ~QAspectJobPrivate();

    static QAspectJobPrivate *get(QAspectJob *job);

    virtual bool isRequired() const;
    virtual void postFrame(QAspectManager *aspectManager);

    void clearDependencies() { m_dependencies.clear(); }

    QVector<QWeakPointer<QAspectJob> > m_dependencies;
    JobId m_jobId;
    QString m_jobName;
};
} // Qt3D

#define SET_JOB_RUN_STAT_TYPE(job, type, instance) \
    { \
        auto djob = Qt3DCore::QAspectJobPrivate::get(job); \
        auto &jobId = djob->m_jobId; \
        jobId.typeAndInstance[0] = type; \
        jobId.typeAndInstance[1] = instance; \
        djob->m_jobName = QLatin1String(#type); \
    }

#define SET_JOB_RUN_STAT_TYPE_AND_NAME(job, type, name, instance) \
    { \
        auto djob = Qt3DCore::QAspectJobPrivate::get(job); \
        auto &jobId = djob->m_jobId; \
        jobId.typeAndInstance[0] = type; \
        jobId.typeAndInstance[1] = instance; \
        djob->m_jobName = QLatin1String(name); \
    }

QT_END_NAMESPACE

#endif // QT3DCORE_QASPECTJOB_P_H

==> qt3d-everywhere-opensource-src-6.2.12.zip: qt3d-everywhere-src-6.2.12/src/core/jobs/qaspectjob_p.h <==
/****************************************************************************
**
** Copyright (C) 2014 Klaralvdalens Datakonsult AB (KDAB).
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt3D module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QT3DCORE_QASPECTJOB_P_H
#define QT3DCORE_QASPECTJOB_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists for the convenience
// of other Qt classes.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <QtCore/QWeakPointer>

#include <Qt3DCore/private/qt3dcore_global_p.h>
#include <Qt3DCore/private/qsysteminformationservice_p_p.h>
#include <Qt3DCore/qt3dcore-config.h>

QT_BEGIN_NAMESPACE

namespace Qt3DCore {

class QAspectJob;
class QAspectManager;

class Q_3DCORE_PRIVATE_EXPORT QAspectJobPrivate
{
public:
    QAspectJobPrivate();
    virtual ~QAspectJobPrivate();

    static QAspectJobPrivate *get(QAspectJob *job);

    virtual bool isRequired() const;
    virtual void postFrame(QAspectManager *aspectManager);

    void clearDependencies() { m_dependencies.clear(); }

    std::vector<QWeakPointer<QAspectJob> > m_dependencies;
    JobId m_jobId;
    QString m_jobName;
};
} // Qt3D

#define SET_JOB_RUN_STAT_TYPE(job, type, instance) \
    { \
        auto djob = Qt3DCore::QAspectJobPrivate::get(job); \
        auto &jobId = djob->m_jobId; \
        jobId.typeAndInstance[0] = type; \
        jobId.typeAndInstance[1] = instance; \
        djob->m_jobName = QLatin1String(#type); \
    }

#define SET_JOB_RUN_STAT_TYPE_AND_NAME(job, type, name, instance) \
    { \
        auto djob = Qt3DCore::QAspectJobPrivate::get(job); \
        auto &jobId = djob->m_jobId; \
        jobId.typeAndInstance[0] = type; \
        jobId.typeAndInstance[1] = instance; \
        djob->m_jobName = QLatin1String(name); \
    }

QT_END_NAMESPACE

#endif // QT3DCORE_QASPECTJOB_P_H
